package edu.vub.nfc;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.LinkedList;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.TextView;

public class ConfigListAdapter extends BaseAdapter {
	
	private LinkedList<WifiConfig> configs_;
	private RawSwipeAndConnectActivity parent_;
	private SQLiteDatabase db_;
	
	public ConfigListAdapter(RawSwipeAndConnectActivity parent) {
		configs_ = new LinkedList<WifiConfig>();
		parent_ = parent;
		db_ = parent_.getWritableConfigDB();
		loadEmAll();
	}

	@Override
	public int getCount() {
		return configs_.size();
	}

	@Override
	public WifiConfig getItem(int position) {
		return configs_.get(position);
	}

	@Override
	public long getItemId(int position) {
		return getItem(position).hashCode();
	}

	@Override
	public View getView(int position, View convertView, ViewGroup vgParent) {
		LayoutInflater i = (LayoutInflater) parent_.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
		//TextView v = (TextView) i.inflate(R.layout.list_item, null);
		TextView v = (TextView) i.inflate(android.R.layout.simple_list_item_1, null);
		v.setText(getItem(position).ssid_);
		return v;
	}
	
	

	@Override
	public boolean isEmpty() {
		return configs_.isEmpty();
	}
	
	public void loadEmAll() {
		Cursor uris = db_.query(
				WifiConfigDb.CONFIGS_TABLE_NAME, 
				new String[] { WifiConfigDb.CONFIGS_TABLE_SSID_COLNAME, WifiConfigDb.CONFIGS_TABLE_KEY_COLNAME }, 
				null, 
				null, 
				null,
				null, 
				WifiConfigDb.CONFIGS_TABLE_DATE_COLNAME + " ASC");
		uris.moveToPosition(-1);
		WifiConfig c;
		while(uris.moveToNext()) {
			c = new WifiConfig(uris.getString(0), uris.getString(1));
			configs_.addFirst(c);
		}
		uris.close();
		notifyDataSetChanged();
	}
	
	public boolean addConfig(WifiConfig c) {
		for (WifiConfig wc : configs_) {
			if (wc.ssid_.equals(c.ssid_)) {
				return false;
			}
		}
		store(c);
		configs_.addFirst(c);
		this.notifyDataSetChanged();
		return true;
	}

	private void store(WifiConfig c) {
		SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss"); 
    	Date date = new Date();
    	ContentValues initialValues = new ContentValues();
    	initialValues.put(WifiConfigDb.CONFIGS_TABLE_SSID_COLNAME, c.ssid_);
    	initialValues.put(WifiConfigDb.CONFIGS_TABLE_KEY_COLNAME, c.key_);
    	initialValues.put(WifiConfigDb.CONFIGS_TABLE_ENCRYPTED_COLNAME, 0);
    	initialValues.put(WifiConfigDb.CONFIGS_TABLE_DATE_COLNAME, dateFormat.format(date));
    	db_.insert(WifiConfigDb.CONFIGS_TABLE_NAME, null, initialValues);
	}

	public void removeAt(int position) {
		WifiConfig c = configs_.remove(position);
		unstore(c);
		this.notifyDataSetChanged();
	}
	
	public void unstore(WifiConfig c) {
		db_.delete(
				WifiConfigDb.CONFIGS_TABLE_NAME, 
				WifiConfigDb.CONFIGS_TABLE_SSID_COLNAME + "=?", new String[] { c.ssid_ });
	}

}
