package edu.vub.nfc;

import java.nio.charset.Charset;

import android.net.wifi.WifiConfiguration;
import android.net.wifi.WifiManager;
import android.nfc.NdefMessage;
import android.nfc.NdefRecord;

public class WifiConfig {

	public String ssid_;
	public String key_;

	public WifiConfig(String ssid, String key) {
		ssid_ = ssid;
		key_ = key; 
	}
	
	public boolean connect(WifiManager wm) {
		WifiConfiguration wc = new WifiConfiguration();
		wc.SSID = "\"" + ssid_ + "\"";
		wc.preSharedKey = "\"" + key_ + "\"";
		wc.status = WifiConfiguration.Status.ENABLED;
		wc.allowedGroupCiphers.set(WifiConfiguration.GroupCipher.TKIP);
		wc.allowedGroupCiphers.set(WifiConfiguration.GroupCipher.CCMP);
		wc.allowedKeyManagement.set(WifiConfiguration.KeyMgmt.WPA_PSK);
		wc.allowedPairwiseCiphers.set(WifiConfiguration.PairwiseCipher.TKIP);
		wc.allowedPairwiseCiphers.set(WifiConfiguration.PairwiseCipher.CCMP);
		wc.allowedProtocols.set(WifiConfiguration.Protocol.RSN);
		int res = wm.addNetwork(wc);
		boolean success = wm.enableNetwork(res, true);
		return success;
	};
	
	public NdefMessage createWifiNdefMessage() {
		NdefRecord joinerRecord = new NdefRecord(
				NdefRecord.TNF_EXTERNAL_TYPE, 
				WifiJoinerType.getBytes(UTF8), 
				new byte[0], 
				"".getBytes(UTF8));
		NdefRecord ssidRecord = new NdefRecord(
				NdefRecord.TNF_EXTERNAL_TYPE, 
				WifiSsidType.getBytes(UTF8), 
				new byte[0], 
				ssid_.getBytes(UTF8));
		String pwdType = WifiPwdType;
		NdefRecord pwdRecord = new NdefRecord(
				NdefRecord.TNF_EXTERNAL_TYPE,
				pwdType.getBytes(UTF8),
				new byte[0],
				key_.getBytes(UTF8));
		return new NdefMessage(new NdefRecord[] {joinerRecord, ssidRecord, pwdRecord});
	}
	
	private static Charset UTF8 = Charset.forName("UTF-8");
	
	public static final String WifiJoinerType = "edu.vub.nfc:wifiJoiner";
	public static final String WifiSsidType = "edu.vub.nfc.wifi:ssid";
	public static final String WifiPwdType = "edu.vub.nfc.wifi:pwd";
		
	public static boolean isWifiJoiner(NdefMessage msg) {
		NdefRecord[] records = msg.getRecords();
		if (records.length == 3) {
			String t1 = new String(records[0].getType());
			String t2 = new String(records[1].getType());
			String t3 = new String(records[2].getType());
			return t1.equals(WifiJoinerType) && t2.equals(WifiSsidType) && (t3.equals(WifiPwdType));
		}
		return false;
	}

}
