package edu.vub.nfc;

import android.os.Bundle;
import edu.vub.AndroidNFC.R;
import edu.vub.nfc.thing.EmptyRecord;
import edu.vub.nfc.thing.listener.ThingSaveFailedListener;
import edu.vub.nfc.thing.listener.ThingSavedListener;

public class CreateWifiJoinerActivity extends AbstractWifiJoinerActivity {
	
	private static final int STATE_NORMAL = 0;
	private static final int STATE_WAITING_FOR_TAG = 1;
	
	private EmptyRecord emptyRecord_;
	
	private int state_ = STATE_NORMAL;
	private WifiConfig pendingWifiConfig_;
	
	@Override
	protected int getContentView() {
		return R.layout.create;
	}

	@Override
	protected String getActivityTitle() {
		return "Create WiFi joiner";
	}

	@Override
	protected String getButtonText() {
		return "Create";
	}

	@Override
	protected void reactOnButtonClick(WifiConfig wc) {
		state_ = STATE_WAITING_FOR_TAG;
		storeIfStateOk(wc);
	}
	
	private void storeIfStateOk(WifiConfig wc) {
		if (state_ != STATE_WAITING_FOR_TAG) {
			return;
		}
		ThingSavedListener<WifiConfig> successListener = new ThingSavedListener<WifiConfig>() {
			@Override
			public void signal(WifiConfig thing) {
				hideSpinner();
				unlock();
				clearTags();
				toast("WiFi joiner created!");
			}
		};
		ThingSaveFailedListener failedListener = new ThingSaveFailedListener() {
			@Override
			public void signal() {
				hideSpinner();
				unlock();
				clearTags();
				toast("Creating WiFi joiner failed, try again.");
			}
			
		};
		setInfo("Creating...");
		lock();
		showSpinner();
		if (wifiConfig_ != null) {
			wifiConfig_.ssid_ = wc.ssid_;
			wifiConfig_.key_ = wc.key_;
			wifiConfig_.saveAsync(successListener, failedListener, 5000);
			state_ = STATE_NORMAL;
		} else if (emptyRecord_ != null) {
			emptyRecord_.initialize(wc, successListener, failedListener, 5000);
			state_ = STATE_NORMAL;
		} else {
			setInfo("Waiting for tag...");
			state_ = STATE_WAITING_FOR_TAG;
			pendingWifiConfig_ = wc;
		}
	}
	
	
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setInfo("Waiting for tag...");
	}

	@Override
	public void whenDiscovered(WifiConfig thing) {
		super.whenDiscovered(thing);
		emptyRecord_ = null;
		storeIfStateOk(pendingWifiConfig_);
	}

	@Override
	public void whenDiscovered(EmptyRecord r) {
		super.whenDiscovered(r);
		emptyRecord_ = r;
		storeIfStateOk(pendingWifiConfig_);
	}
	
	
	private void clearTags() {
		wifiConfig_ = null;
		emptyRecord_ = null;
	}
}
